# automx2: Email client configuration made easy

automx2 makes configuring a mail account easy. It unites methods for automated mailbox configuration from Apple
[mobileconfig](https://support.apple.com/de-de/guide/profile-manager/pmdbd71ebc9/mac), Microsoft
[autodiscover](https://docs.microsoft.com/de-de/exchange/architecture/client-access/autodiscover?view=exchserver-2019)
and Mozilla [autoconfig](https://developer.mozilla.org/de/docs/Mozilla/Thunderbird/Autokonfiguration) in one tool.
automx2 is successor to automx. It has been designed to be easier to setup, easier to configure and easier to use.

## Documentation

automx2 comes with documentation that explains how automated mail account configuration works, how automx2 works and how
you install and configure automx2.

All [documentation](https://gitlab.com/automx/automx2/blob/master/doc/automx2.adoc) is stored in the doc subdirectory.
You can read it file by file using a text reader or all files as one if you point your browser to +automx2.html+.

## About automx2

The project resides as [automx/automx2](https://gitlab.com/automx/automx2) on GitLab. Please use the project's [issue
tracker](https://gitlab.com/automx/automx2/issues) if you find bugs. To discuss usage and other topics join us on the
[automx-users](https://mail.sys4.de/cgi-bin/mailman/listinfo/automx-users) mailing list.

automx2 was written by [Ralph Seichter](https://gitlab.com/rseichter) for [sys4 AG](https://sys4.de). It has 100% test
coverage and is mirrored to [rseichter/automx2](https://github.com/rseichter/automx2) on GitHub.
